@@ -52,6 +52,9 @@ class LocalTutorialRunner(RunnerBase):
                     clear_environment=test.clear_environment,
                 )
 
+                # Update environment regardless of success of command
+                self.environment.update({k: self.render(v) for k, v in test.update_environment.items()})
+
                 if test.status_code == test_proc.returncode:
                     return
                 else:
@@ -127,14 +130,21 @@ class LocalTutorialRunner(RunnerBase):
             # Update the context from update_context
             self.context.update(command_config.run.update_context)
 
-            if command_config.run.chdir is not None:
-                log.info("Changing working directory to %s.", command_config.run.chdir)
-                os.chdir(command_config.run.chdir)
+            if (command_chdir := command_config.run.chdir) is not None:
+                rendered_command_chdir = self.render(str(command_chdir))
+                rendered_command_chdir = self.render(str(command_chdir))
+                log.info("Changing working directory to %s.", command_chdir)
+                os.chdir(rendered_command_chdir)
 
             # Run test commands
             for test_command_config in command_config.run.test:
                 self.run_test(test_command_config, proc)
 
+            # Update environment (after test commands - they may update the context)
+            self.environment.update(
+                {k: self.render(v) for k, v in command_config.run.update_environment.items()}
+            )
+
     def write_file(self, part: FilePartModel) -> None:
         """Write a file."""
         raw_destination = self.render(part.destination)
