@@ -6,7 +6,7 @@
 import io
 import os
 import subprocess
-from pathlib import Path
+from typing import Any
 from unittest import mock
 
 import pytest
@@ -64,19 +64,37 @@ def test_command_as_list(fp: FakeProcess, runner: LocalTutorialRunner) -> None:
     recorder_test = fp.register(["ls", "test with spaces"])
     recorder_cleanup = fp.register(["ls", "cleanup with spaces"])
     runner.run()
-    expected = {"shell": False, "stdin": None, "stderr": None, "stdout": None, "env": None}
+    expected: dict[str, Any] = {"shell": False, "stdin": None, "stderr": None, "stdout": None, "env": {}}
     assert recorder_main.calls[0].kwargs == expected
     assert recorder_test.calls[0].kwargs == expected
     assert recorder_cleanup.calls[0].kwargs == expected
 
 
+@pytest.mark.tutorial("command-skip-single-command")
+def test_command_skip_single_command(fp: FakeProcess, runner: LocalTutorialRunner) -> None:
+    """Run a tutorial where a single command is skipped."""
+    fp.register("echo 1")
+    fp.register("echo 2")
+    # echo 3 is skipped at runtime
+    runner.run()
+
+
 @pytest.mark.tutorial("command-with-chdir")
 def test_command_with_chdir(fp: FakeProcess, runner: LocalTutorialRunner) -> None:
     """Test changing the working directory after a command."""
     fp.register("ls")
     with mock.patch("os.chdir", autospec=True) as mock_chdir:
         runner.run()
-    mock_chdir.assert_called_once_with(Path("/does/not/exist"))
+    mock_chdir.assert_called_once_with("/does/not/exist")
+
+
+@pytest.mark.tutorial("command-with-chdir-template")
+def test_command_with_chdir_with_template(fp: FakeProcess, runner: LocalTutorialRunner) -> None:
+    """Test changing the working directory after a command."""
+    fp.register("ls")
+    with mock.patch("os.chdir", autospec=True) as mock_chdir:
+        runner.run()
+    mock_chdir.assert_called_once_with("/does/not/exist")
 
 
 @pytest.mark.tutorial("command-stdin")
@@ -103,12 +121,12 @@ def test_command_hide_output(fp: FakeProcess, runner: LocalTutorialRunner) -> No
     recorder_test = fp.register("ls test")
     recorder_cleanup = fp.register("ls cleanup")
     runner.run()
-    expected = {
+    expected: dict[str, Any] = {
         "shell": True,
         "stdin": None,
         "stderr": subprocess.DEVNULL,
         "stdout": subprocess.DEVNULL,
-        "env": None,
+        "env": {},
     }
     assert recorder_main.calls[0].kwargs == expected
     assert recorder_test.calls[0].kwargs == expected
@@ -122,12 +140,12 @@ def test_command_capture_output(
     """Test running a commands with capturing the output."""
     recorder = fp.register("echo foo bar bla", stdout="foo bar bla", stderr="foo bla bla")
     runner.run()
-    expected = {
+    expected: dict[str, Any] = {
         "shell": True,
         "stdin": None,
         "stderr": subprocess.PIPE,
         "stdout": subprocess.PIPE,
-        "env": None,
+        "env": {},
     }
     assert recorder.calls[0].kwargs == expected
     output = capsys.readouterr()
@@ -168,22 +186,6 @@ def test_command_with_invalid_output(fp: FakeProcess, runner: LocalTutorialRunne
         runner.run()
 
 
-@pytest.mark.tutorial("command-simple-env")
-def test_environment(fp: FakeProcess, runner: LocalTutorialRunner) -> None:
-    """Test running a commands with environment variables."""
-    recorder1 = fp.register("echo 1 $VARIABLE")
-    recorder2 = fp.register("echo 2 $VARIABLE")
-    runner.run()
-    assert recorder1.calls[0].kwargs["env"]["VARIABLE"] == "VALUE 1"  # type: ignore[index]
-    assert recorder2.calls[0].kwargs == {
-        "shell": True,
-        "stdin": None,
-        "stderr": None,
-        "stdout": None,
-        "env": {"VARIABLE": "VALUE 2"},
-    }
-
-
 @pytest.mark.doc_tutorial("test-command")
 def test_test_commands_with_command_error(fp: FakeProcess, doc_runner: LocalTutorialRunner) -> None:
     """Test the cleanup from docs."""
